@@ -1,5 +1,3 @@
-from typing import Any
-
 from translators import apis  # type: ignore
 
 from md_translate import const
@@ -11,12 +9,3 @@ def get_translator_by_service_name(service_name: str) -> apis.Tse:
     if translator_class is None:
         raise UnknownServiceError(service_name)
     return translator_class
-
-
-class Singletone:
-    instance = None
-
-    def __new__(cls) -> Any:
-        if cls.instance is None:
-            cls.instance = super(Singletone, cls).__new__(cls)
-        return cls.instance
